@@ -98,12 +98,9 @@ def filter_submissions(submission_list, user_list):
         yield submission
         break
 def format_submission_short(submission):
-  if submission.submitted_at:
-    date = submission.submitted_at
-  else:
-    date = submission.graded_at
   return [submission.assignment.course.course_code, submission.assignment.name,
-    submission.user_id, submission.user.name, submission.grade, date]
+    submission.user.name, submission.grade,
+    submission.submitted_at, submission.graded_at]
 def format_submission(submission, canvas):
   """Formats submission for printing to stdout"""
   student = submission.assignment.course.get_user(submission.user_id)
@@ -171,7 +168,8 @@ def add_submissions_command(subp):
   submissions_parser = subp.add_parser("submissions",
       help="Lists submissions of an assignment",
       description="Lists submissions of assignment(s). Output format: "
-        "<Canvas-user-ID> <grade> <grade date>")
+        "<course code> <assignment name> <user> <grade> "
+        "<submission date> <grade date>")
   submissions_parser.set_defaults(func=submissions_command)
   assignments.add_assignment_option(submissions_parser)
   add_submission_options(submissions_parser)
